@@ -4,7 +4,7 @@ import * as reportUtils from '@tamanu/shared/reports';
 import { checkReportModulePermissions } from '@tamanu/shared/reports/utilities/checkReportModulePermissions';
 import { createNamedLogger } from '@tamanu/shared/services/logging/createNamedLogger';
 import { getAvailableReports } from '@tamanu/shared/reports/utilities/getAvailableReports';
-import { NotFoundError } from '@tamanu/shared/errors';
+import { NotFoundError } from '@tamanu/errors';
 import { assertReportEnabled } from '../../utils/assertReportEnabled';
 
 const FACILITY_REPORT_LOG_NAME = 'FacilityReport';
